@@ -6,6 +6,7 @@
 
 import dataclasses
 from pathlib import Path
+from typing import Optional
 
 from jinja2 import Environment
 from jinja2 import FileSystemLoader
@@ -15,24 +16,30 @@ from pythogen import settings
 
 @dataclasses.dataclass
 class InitPackageResponse:
-    output_path: str
+    client_output_path: str
 
 
-def init_package(*, client_class_name: str, package_version: str) -> InitPackageResponse:
+def init_package(
+    *,
+    output_path: str,
+    client_class_name: str,
+    package_version: str,
+    package_authors: Optional[str] = None,
+) -> InitPackageResponse:
     package_name = f"{client_class_name.lower().replace('client', '')}_client"
 
     pyproject_path = Path(output_path).joinpath(package_name)
     pyproject_path.mkdir(parents=True, exist_ok=True)
-    _create_pyproject_file(pyproject_path, package_name, package_version)
+    _create_pyproject_file(pyproject_path, package_name, package_version, package_authors)
 
     sources_path = pyproject_path.joinpath(package_name)
     sources_path.mkdir(parents=True, exist_ok=True)
     _create_init_file(sources_path, package_name)
 
-    sources_path.joinpath(f'{package_name}.py')
+    return InitPackageResponse(client_output_path=sources_path.joinpath(f'{package_name}.py'))
 
 
-def _create_pyproject_file(output_dir: Path, package_name: str, version: str) -> None:
+def _create_pyproject_file(output_dir: Path, package_name: str, version: str, authors: Optional[str] = None) -> None:
     env = Environment(
         loader=FileSystemLoader(settings.TEMPLATES_DIR_PATH),
         extensions=['jinja2.ext.loopcontrols'],
@@ -46,6 +53,7 @@ def _create_pyproject_file(output_dir: Path, package_name: str, version: str) ->
             template.render(
                 name=package_name,
                 version=version,
+                authors=authors,
             )
         )
 
